@@ -2,11 +2,11 @@
 #include <RcppEigen.h>
 #include <R.h>
 
-std::list < struct Particle > Get_Particle_Descendents_W(const struct Particle & Ancestor, int ii, int Number, double likelihood, const double & sigma_hat, double Sigma_Inn_comp, double Numerator, double Denominator, 
+std::list <Particle > Get_Particle_Descendents_W(Particle & Ancestor, int ii, int Number, double likelihood, const double & sigma_hat, double Sigma_Inn_comp, double Numerator, double Denominator, 
 double s, double General_weight, int horizon)
 {
 
-	std::list < struct Particle > out;
+	std::list < Particle > out;
 
 	double sampled_scale, Common_weight, specific_weight, parameter, tmp, factor;
 
